/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSensors.h"

#line 74 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtapsensor.sip"
#include <qtapsensor.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtapsensor.sip"
#include <qtapsensor.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 85 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#include <qpair.h>
#line 64 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQTapSensor.cpp"


class sipQTapSensor : public ::QTapSensor
{
public:
    sipQTapSensor(::QObject*);
    virtual ~sipQTapSensor();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTapSensor(const sipQTapSensor &);
    sipQTapSensor &operator = (const sipQTapSensor &);

    char sipPyMethods[7];
};

sipQTapSensor::sipQTapSensor(::QObject*a0): ::QTapSensor(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTapSensor::~sipQTapSensor()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQTapSensor::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSensors_qt_metaobject(sipPySelf, sipType_QTapSensor);

    return ::QTapSensor::metaObject();
}

int sipQTapSensor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QTapSensor::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSensors_qt_metacall(sipPySelf, sipType_QTapSensor, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQTapSensor::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSensors_qt_metacast(sipPySelf, sipType_QTapSensor, _clname, &sipCpp) ? sipCpp : ::QTapSensor::qt_metacast(_clname));
}

void sipQTapSensor::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QTapSensor::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSensors_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSensors_0(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTapSensor::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QTapSensor::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSensors_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSensors_0(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTapSensor::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QTapSensor::customEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSensors_1(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTapSensor::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QTapSensor::childEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSensors_2(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTapSensor::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QTapSensor::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSensors_3(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTapSensor::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QTapSensor::eventFilter(a0, a1);

    extern bool sipVH_QtSensors_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSensors_4(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQTapSensor::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QTapSensor::event(a0);

    extern bool sipVH_QtSensors_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSensors_5(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QTapSensor_reading, "reading(self) -> Optional[QTapReading]");

extern "C" {static PyObject *meth_QTapSensor_reading(PyObject *, PyObject *);}
static PyObject *meth_QTapSensor_reading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTapSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTapSensor, &sipCpp))
        {
            ::QTapReading*sipRes;

            sipRes = sipCpp->reading();

            return sipConvertFromType(sipRes, sipType_QTapReading, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTapSensor, sipName_reading, doc_QTapSensor_reading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTapSensor_returnDoubleTapEvents, "returnDoubleTapEvents(self) -> bool");

extern "C" {static PyObject *meth_QTapSensor_returnDoubleTapEvents(PyObject *, PyObject *);}
static PyObject *meth_QTapSensor_returnDoubleTapEvents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTapSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTapSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->returnDoubleTapEvents();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTapSensor, sipName_returnDoubleTapEvents, doc_QTapSensor_returnDoubleTapEvents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTapSensor_setReturnDoubleTapEvents, "setReturnDoubleTapEvents(self, returnDoubleTapEvents: bool)");

extern "C" {static PyObject *meth_QTapSensor_setReturnDoubleTapEvents(PyObject *, PyObject *);}
static PyObject *meth_QTapSensor_setReturnDoubleTapEvents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QTapSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QTapSensor, &sipCpp, &a0))
        {
            sipCpp->setReturnDoubleTapEvents(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTapSensor, sipName_setReturnDoubleTapEvents, doc_QTapSensor_setReturnDoubleTapEvents);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTapSensor(void *, const sipTypeDef *);}
static void *cast_QTapSensor(void *sipCppV, const sipTypeDef *targetType)
{
    ::QTapSensor *sipCpp = reinterpret_cast< ::QTapSensor *>(sipCppV);

    if (targetType == sipType_QTapSensor)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSensor)->ctd_cast(static_cast< ::QSensor *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTapSensor(void *, int);}
static void release_QTapSensor(void *sipCppV, int)
{
    ::QTapSensor *sipCpp = reinterpret_cast< ::QTapSensor *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QTapSensor(Py_ssize_t);}
static void *array_QTapSensor(Py_ssize_t sipNrElem)
{
    return new ::QTapSensor[sipNrElem];
}


extern "C" {static void array_delete_QTapSensor(void *);}
static void array_delete_QTapSensor(void *sipCpp)
{
    delete[] reinterpret_cast< ::QTapSensor *>(sipCpp);
}


extern "C" {static void dealloc_QTapSensor(sipSimpleWrapper *);}
static void dealloc_QTapSensor(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTapSensor *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTapSensor(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTapSensor(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTapSensor(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQTapSensor *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQTapSensor(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTapSensor[] = {{56, 255, 1}};


static PyMethodDef methods_QTapSensor[] = {
    {sipName_reading, meth_QTapSensor_reading, METH_VARARGS, doc_QTapSensor_reading},
    {sipName_returnDoubleTapEvents, meth_QTapSensor_returnDoubleTapEvents, METH_VARARGS, doc_QTapSensor_returnDoubleTapEvents},
    {sipName_setReturnDoubleTapEvents, meth_QTapSensor_setReturnDoubleTapEvents, METH_VARARGS, doc_QTapSensor_setReturnDoubleTapEvents}
};

PyDoc_STRVAR(doc_QTapSensor, "\1QTapSensor(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QTapSensor[] = {
    {"returnDoubleTapEventsChanged(bool)", "\1returnDoubleTapEventsChanged(self, returnDoubleTapEvents: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QTapSensor = {
    &::QTapSensor::staticMetaObject,
    0,
    signals_QTapSensor,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSensors_QTapSensor = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTapSensor,
        SIP_NULLPTR,
        &plugin_QTapSensor,
    },
    {
        sipNameNr_QTapSensor,
        {0, 0, 1},
        3, methods_QTapSensor,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTapSensor,
    -1,
    -1,
    supers_QTapSensor,
    SIP_NULLPTR,
    init_type_QTapSensor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTapSensor,
    SIP_NULLPTR,
    array_QTapSensor,
    SIP_NULLPTR,
    release_QTapSensor,
    cast_QTapSensor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QTapSensor,
    sizeof (::QTapSensor),
};
