/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraexposurecontrol.sip"
#include <qcameraexposurecontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraExposureControl.cpp"


class sipQCameraExposureControl : public ::QCameraExposureControl
{
public:
    sipQCameraExposureControl(::QObject*);
    virtual ~sipQCameraExposureControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool setValue(::QCameraExposureControl::ExposureParameter, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant actualValue(::QCameraExposureControl::ExposureParameter) const SIP_OVERRIDE;
    ::QVariant requestedValue(::QCameraExposureControl::ExposureParameter) const SIP_OVERRIDE;
    ::QVariantList supportedParameterRange(::QCameraExposureControl::ExposureParameter, bool*) const SIP_OVERRIDE;
    bool isParameterSupported(::QCameraExposureControl::ExposureParameter) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraExposureControl(const sipQCameraExposureControl &);
    sipQCameraExposureControl &operator = (const sipQCameraExposureControl &);

    char sipPyMethods[12];
};

sipQCameraExposureControl::sipQCameraExposureControl(::QObject*a0): ::QCameraExposureControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraExposureControl::~sipQCameraExposureControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraExposureControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraExposureControl);

    return ::QCameraExposureControl::metaObject();
}

int sipQCameraExposureControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraExposureControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraExposureControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraExposureControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraExposureControl, _clname, &sipCpp) ? sipCpp : ::QCameraExposureControl::qt_metacast(_clname));
}

bool sipQCameraExposureControl::setValue(::QCameraExposureControl::ExposureParameter a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QCameraExposureControl, sipName_setValue);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraExposureControl::ExposureParameter, const ::QVariant&);

    return sipVH_QtMultimedia_57(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQCameraExposureControl::actualValue(::QCameraExposureControl::ExposureParameter a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraExposureControl, sipName_actualValue);

    if (!sipMeth)
        return ::QVariant();

    extern ::QVariant sipVH_QtMultimedia_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraExposureControl::ExposureParameter);

    return sipVH_QtMultimedia_56(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQCameraExposureControl::requestedValue(::QCameraExposureControl::ExposureParameter a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraExposureControl, sipName_requestedValue);

    if (!sipMeth)
        return ::QVariant();

    extern ::QVariant sipVH_QtMultimedia_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraExposureControl::ExposureParameter);

    return sipVH_QtMultimedia_56(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariantList sipQCameraExposureControl::supportedParameterRange(::QCameraExposureControl::ExposureParameter a0, bool*a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraExposureControl, sipName_supportedParameterRange);

    if (!sipMeth)
        return ::QVariantList();

    extern ::QVariantList sipVH_QtMultimedia_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraExposureControl::ExposureParameter, bool*);

    return sipVH_QtMultimedia_55(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraExposureControl::isParameterSupported(::QCameraExposureControl::ExposureParameter a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraExposureControl, sipName_isParameterSupported);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraExposureControl::ExposureParameter);

    return sipVH_QtMultimedia_54(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraExposureControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraExposureControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraExposureControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraExposureControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraExposureControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraExposureControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraExposureControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraExposureControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraExposureControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraExposureControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraExposureControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraExposureControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraExposureControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraExposureControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraExposureControl_isParameterSupported, "isParameterSupported(self, parameter: QCameraExposureControl.ExposureParameter) -> bool");

extern "C" {static PyObject *meth_QCameraExposureControl_isParameterSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraExposureControl_isParameterSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraExposureControl::ExposureParameter a0;
        const ::QCameraExposureControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraExposureControl, &sipCpp, sipType_QCameraExposureControl_ExposureParameter, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraExposureControl, sipName_isParameterSupported);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isParameterSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraExposureControl, sipName_isParameterSupported, doc_QCameraExposureControl_isParameterSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraExposureControl_supportedParameterRange, "supportedParameterRange(self, parameter: QCameraExposureControl.ExposureParameter) -> (list[Any], Optional[bool])");

extern "C" {static PyObject *meth_QCameraExposureControl_supportedParameterRange(PyObject *, PyObject *);}
static PyObject *meth_QCameraExposureControl_supportedParameterRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraExposureControl::ExposureParameter a0;
        bool a1;
        const ::QCameraExposureControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraExposureControl, &sipCpp, sipType_QCameraExposureControl_ExposureParameter, &a0))
        {
            ::QVariantList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraExposureControl, sipName_supportedParameterRange);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariantList(sipCpp->supportedParameterRange(a0, &a1));

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QList_0100QVariant, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraExposureControl, sipName_supportedParameterRange, doc_QCameraExposureControl_supportedParameterRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraExposureControl_requestedValue, "requestedValue(self, parameter: QCameraExposureControl.ExposureParameter) -> Any");

extern "C" {static PyObject *meth_QCameraExposureControl_requestedValue(PyObject *, PyObject *);}
static PyObject *meth_QCameraExposureControl_requestedValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraExposureControl::ExposureParameter a0;
        const ::QCameraExposureControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraExposureControl, &sipCpp, sipType_QCameraExposureControl_ExposureParameter, &a0))
        {
            ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraExposureControl, sipName_requestedValue);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariant(sipCpp->requestedValue(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraExposureControl, sipName_requestedValue, doc_QCameraExposureControl_requestedValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraExposureControl_actualValue, "actualValue(self, parameter: QCameraExposureControl.ExposureParameter) -> Any");

extern "C" {static PyObject *meth_QCameraExposureControl_actualValue(PyObject *, PyObject *);}
static PyObject *meth_QCameraExposureControl_actualValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraExposureControl::ExposureParameter a0;
        const ::QCameraExposureControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraExposureControl, &sipCpp, sipType_QCameraExposureControl_ExposureParameter, &a0))
        {
            ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraExposureControl, sipName_actualValue);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariant(sipCpp->actualValue(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraExposureControl, sipName_actualValue, doc_QCameraExposureControl_actualValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraExposureControl_setValue, "setValue(self, parameter: QCameraExposureControl.ExposureParameter, value: Any) -> bool");

extern "C" {static PyObject *meth_QCameraExposureControl_setValue(PyObject *, PyObject *);}
static PyObject *meth_QCameraExposureControl_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraExposureControl::ExposureParameter a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QCameraExposureControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QCameraExposureControl, &sipCpp, sipType_QCameraExposureControl_ExposureParameter, &a0, sipType_QVariant, &a1, &a1State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraExposureControl, sipName_setValue);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setValue(a0, *a1);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraExposureControl, sipName_setValue, doc_QCameraExposureControl_setValue);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraExposureControl(void *, const sipTypeDef *);}
static void *cast_QCameraExposureControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraExposureControl *sipCpp = reinterpret_cast< ::QCameraExposureControl *>(sipCppV);

    if (targetType == sipType_QCameraExposureControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraExposureControl(void *, int);}
static void release_QCameraExposureControl(void *sipCppV, int)
{
    ::QCameraExposureControl *sipCpp = reinterpret_cast< ::QCameraExposureControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraExposureControl(sipSimpleWrapper *);}
static void dealloc_QCameraExposureControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraExposureControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraExposureControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraExposureControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraExposureControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraExposureControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraExposureControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraExposureControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraExposureControl[] = {
    {sipName_actualValue, meth_QCameraExposureControl_actualValue, METH_VARARGS, doc_QCameraExposureControl_actualValue},
    {sipName_isParameterSupported, meth_QCameraExposureControl_isParameterSupported, METH_VARARGS, doc_QCameraExposureControl_isParameterSupported},
    {sipName_requestedValue, meth_QCameraExposureControl_requestedValue, METH_VARARGS, doc_QCameraExposureControl_requestedValue},
    {sipName_setValue, meth_QCameraExposureControl_setValue, METH_VARARGS, doc_QCameraExposureControl_setValue},
    {sipName_supportedParameterRange, meth_QCameraExposureControl_supportedParameterRange, METH_VARARGS, doc_QCameraExposureControl_supportedParameterRange}
};

static sipEnumMemberDef enummembers_QCameraExposureControl[] = {
    {sipName_Aperture, static_cast<int>(::QCameraExposureControl::Aperture), 52},
    {sipName_ExposureCompensation, static_cast<int>(::QCameraExposureControl::ExposureCompensation), 52},
    {sipName_ExposureMode, static_cast<int>(::QCameraExposureControl::ExposureMode), 52},
    {sipName_ExtendedExposureParameter, static_cast<int>(::QCameraExposureControl::ExtendedExposureParameter), 52},
    {sipName_FlashCompensation, static_cast<int>(::QCameraExposureControl::FlashCompensation), 52},
    {sipName_FlashPower, static_cast<int>(::QCameraExposureControl::FlashPower), 52},
    {sipName_ISO, static_cast<int>(::QCameraExposureControl::ISO), 52},
    {sipName_MeteringMode, static_cast<int>(::QCameraExposureControl::MeteringMode), 52},
    {sipName_ShutterSpeed, static_cast<int>(::QCameraExposureControl::ShutterSpeed), 52},
    {sipName_SpotMeteringPoint, static_cast<int>(::QCameraExposureControl::SpotMeteringPoint), 52},
    {sipName_TorchPower, static_cast<int>(::QCameraExposureControl::TorchPower), 52},
};

PyDoc_STRVAR(doc_QCameraExposureControl, "\1QCameraExposureControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraExposureControl[] = {
    {"parameterRangeChanged(int)", "\1parameterRangeChanged(self, parameter: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"actualValueChanged(int)", "\1actualValueChanged(self, parameter: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"requestedValueChanged(int)", "\1requestedValueChanged(self, parameter: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraExposureControl = {
    &::QCameraExposureControl::staticMetaObject,
    0,
    signals_QCameraExposureControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraExposureControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraExposureControl,
        SIP_NULLPTR,
        &plugin_QCameraExposureControl,
    },
    {
        sipNameNr_QCameraExposureControl,
        {0, 0, 1},
        5, methods_QCameraExposureControl,
        11, enummembers_QCameraExposureControl,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraExposureControl,
    -1,
    -1,
    supers_QCameraExposureControl,
    SIP_NULLPTR,
    init_type_QCameraExposureControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraExposureControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraExposureControl,
    cast_QCameraExposureControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraExposureControl),
};
