/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qopengltimerquery.sip"
#include <qopengltimerquery.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipQtGuiQOpenGLTimerQuery.cpp"


class sipQOpenGLTimerQuery : public ::QOpenGLTimerQuery
{
public:
    sipQOpenGLTimerQuery(::QObject*);
    virtual ~sipQOpenGLTimerQuery();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLTimerQuery(const sipQOpenGLTimerQuery &);
    sipQOpenGLTimerQuery &operator = (const sipQOpenGLTimerQuery &);

    char sipPyMethods[7];
};

sipQOpenGLTimerQuery::sipQOpenGLTimerQuery(::QObject*a0): ::QOpenGLTimerQuery(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLTimerQuery::~sipQOpenGLTimerQuery()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQOpenGLTimerQuery::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtGui_qt_metaobject(sipPySelf, sipType_QOpenGLTimerQuery);

    return ::QOpenGLTimerQuery::metaObject();
}

int sipQOpenGLTimerQuery::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QOpenGLTimerQuery::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtGui_qt_metacall(sipPySelf, sipType_QOpenGLTimerQuery, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQOpenGLTimerQuery::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtGui_qt_metacast(sipPySelf, sipType_QOpenGLTimerQuery, _clname, &sipCpp) ? sipCpp : ::QOpenGLTimerQuery::qt_metacast(_clname));
}

bool sipQOpenGLTimerQuery::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QOpenGLTimerQuery::event(a0);

    extern bool sipVH_QtGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtGui_5(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQOpenGLTimerQuery::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QOpenGLTimerQuery::eventFilter(a0, a1);

    extern bool sipVH_QtGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtGui_4(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOpenGLTimerQuery::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QOpenGLTimerQuery::timerEvent(a0);
        return;
    }

    extern void sipVH_QtGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtGui_3(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLTimerQuery::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QOpenGLTimerQuery::childEvent(a0);
        return;
    }

    extern void sipVH_QtGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtGui_2(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLTimerQuery::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QOpenGLTimerQuery::customEvent(a0);
        return;
    }

    extern void sipVH_QtGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtGui_1(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLTimerQuery::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QOpenGLTimerQuery::connectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOpenGLTimerQuery::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QOpenGLTimerQuery::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtGui_0(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_create, "create(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_create(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_create(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->create();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_create, doc_QOpenGLTimerQuery_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_destroy, "destroy(self)");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_destroy(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_destroy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            sipCpp->destroy();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_destroy, doc_QOpenGLTimerQuery_destroy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_isCreated, "isCreated(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_isCreated(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_isCreated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCreated();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_isCreated, doc_QOpenGLTimerQuery_isCreated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_objectId, "objectId(self) -> int");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_objectId(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_objectId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->objectId();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_objectId, doc_QOpenGLTimerQuery_objectId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_begin, "begin(self)");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_begin(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_begin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            sipCpp->begin();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_begin, doc_QOpenGLTimerQuery_begin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_end, "end(self)");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_end(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_end(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            sipCpp->end();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_end, doc_QOpenGLTimerQuery_end);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_waitForTimestamp, "waitForTimestamp(self) -> int");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_waitForTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_waitForTimestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            ::GLuint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForTimestamp();
            Py_END_ALLOW_THREADS

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_waitForTimestamp, doc_QOpenGLTimerQuery_waitForTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_recordTimestamp, "recordTimestamp(self)");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_recordTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_recordTimestamp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            sipCpp->recordTimestamp();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_recordTimestamp, doc_QOpenGLTimerQuery_recordTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_isResultAvailable, "isResultAvailable(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_isResultAvailable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_isResultAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isResultAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_isResultAvailable, doc_QOpenGLTimerQuery_isResultAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLTimerQuery_waitForResult, "waitForResult(self) -> int");

extern "C" {static PyObject *meth_QOpenGLTimerQuery_waitForResult(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLTimerQuery_waitForResult(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOpenGLTimerQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLTimerQuery, &sipCpp))
        {
            ::GLuint64 sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForResult();
            Py_END_ALLOW_THREADS

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLTimerQuery, sipName_waitForResult, doc_QOpenGLTimerQuery_waitForResult);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLTimerQuery(void *, const sipTypeDef *);}
static void *cast_QOpenGLTimerQuery(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOpenGLTimerQuery *sipCpp = reinterpret_cast< ::QOpenGLTimerQuery *>(sipCppV);

    if (targetType == sipType_QOpenGLTimerQuery)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLTimerQuery(void *, int);}
static void release_QOpenGLTimerQuery(void *sipCppV, int)
{
    ::QOpenGLTimerQuery *sipCpp = reinterpret_cast< ::QOpenGLTimerQuery *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QOpenGLTimerQuery(Py_ssize_t);}
static void *array_QOpenGLTimerQuery(Py_ssize_t sipNrElem)
{
    return new ::QOpenGLTimerQuery[sipNrElem];
}


extern "C" {static void array_delete_QOpenGLTimerQuery(void *);}
static void array_delete_QOpenGLTimerQuery(void *sipCpp)
{
    delete[] reinterpret_cast< ::QOpenGLTimerQuery *>(sipCpp);
}


extern "C" {static void dealloc_QOpenGLTimerQuery(sipSimpleWrapper *);}
static void dealloc_QOpenGLTimerQuery(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLTimerQuery *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLTimerQuery(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLTimerQuery(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLTimerQuery(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQOpenGLTimerQuery *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQOpenGLTimerQuery(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLTimerQuery[] = {{25, 0, 1}};


static PyMethodDef methods_QOpenGLTimerQuery[] = {
    {sipName_begin, meth_QOpenGLTimerQuery_begin, METH_VARARGS, doc_QOpenGLTimerQuery_begin},
    {sipName_create, meth_QOpenGLTimerQuery_create, METH_VARARGS, doc_QOpenGLTimerQuery_create},
    {sipName_destroy, meth_QOpenGLTimerQuery_destroy, METH_VARARGS, doc_QOpenGLTimerQuery_destroy},
    {sipName_end, meth_QOpenGLTimerQuery_end, METH_VARARGS, doc_QOpenGLTimerQuery_end},
    {sipName_isCreated, meth_QOpenGLTimerQuery_isCreated, METH_VARARGS, doc_QOpenGLTimerQuery_isCreated},
    {sipName_isResultAvailable, meth_QOpenGLTimerQuery_isResultAvailable, METH_VARARGS, doc_QOpenGLTimerQuery_isResultAvailable},
    {sipName_objectId, meth_QOpenGLTimerQuery_objectId, METH_VARARGS, doc_QOpenGLTimerQuery_objectId},
    {sipName_recordTimestamp, meth_QOpenGLTimerQuery_recordTimestamp, METH_VARARGS, doc_QOpenGLTimerQuery_recordTimestamp},
    {sipName_waitForResult, meth_QOpenGLTimerQuery_waitForResult, METH_VARARGS, doc_QOpenGLTimerQuery_waitForResult},
    {sipName_waitForTimestamp, meth_QOpenGLTimerQuery_waitForTimestamp, METH_VARARGS, doc_QOpenGLTimerQuery_waitForTimestamp}
};

PyDoc_STRVAR(doc_QOpenGLTimerQuery, "\1QOpenGLTimerQuery(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QOpenGLTimerQuery = {
    &::QOpenGLTimerQuery::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QOpenGLTimerQuery = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLTimerQuery,
        SIP_NULLPTR,
        &plugin_QOpenGLTimerQuery,
    },
    {
        sipNameNr_QOpenGLTimerQuery,
        {0, 0, 1},
        10, methods_QOpenGLTimerQuery,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLTimerQuery,
    -1,
    -1,
    supers_QOpenGLTimerQuery,
    SIP_NULLPTR,
    init_type_QOpenGLTimerQuery,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLTimerQuery,
    SIP_NULLPTR,
    array_QOpenGLTimerQuery,
    SIP_NULLPTR,
    release_QOpenGLTimerQuery,
    cast_QOpenGLTimerQuery,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOpenGLTimerQuery,
    sizeof (::QOpenGLTimerQuery),
};
