/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 47 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchengine.sip"
#include <qhelpsearchengine.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpenginecore.sip"
#include <qhelpenginecore.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchengine.sip"
#include <qhelpsearchengine.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchengine.sip"
#include <qhelpsearchengine.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 263 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#include <qpair.h>
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchresultwidget.sip"
#include <qhelpsearchresultwidget.h>
#line 58 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchquerywidget.sip"
#include <qhelpsearchquerywidget.h>
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchEngine.cpp"


class sipQHelpSearchEngine : public ::QHelpSearchEngine
{
public:
    sipQHelpSearchEngine(::QHelpEngineCore*, ::QObject*);
    virtual ~sipQHelpSearchEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHelpSearchEngine(const sipQHelpSearchEngine &);
    sipQHelpSearchEngine &operator = (const sipQHelpSearchEngine &);

    char sipPyMethods[7];
};

sipQHelpSearchEngine::sipQHelpSearchEngine(::QHelpEngineCore*a0, ::QObject*a1): ::QHelpSearchEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHelpSearchEngine::~sipQHelpSearchEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHelpSearchEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtHelp_qt_metaobject(sipPySelf, sipType_QHelpSearchEngine);

    return ::QHelpSearchEngine::metaObject();
}

int sipQHelpSearchEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHelpSearchEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtHelp_qt_metacall(sipPySelf, sipType_QHelpSearchEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHelpSearchEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtHelp_qt_metacast(sipPySelf, sipType_QHelpSearchEngine, _clname, &sipCpp) ? sipCpp : ::QHelpSearchEngine::qt_metacast(_clname));
}

bool sipQHelpSearchEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHelpSearchEngine::event(a0);

    extern bool sipVH_QtHelp_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtHelp_24(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpSearchEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHelpSearchEngine::eventFilter(a0, a1);

    extern bool sipVH_QtHelp_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtHelp_25(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQHelpSearchEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHelpSearchEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtHelp_26(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHelpSearchEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtHelp_27(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHelpSearchEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtHelp_28(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHelpSearchEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpSearchEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHelpSearchEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHelpSearchEngine_query, "query(self) -> list[QHelpSearchQuery]");

extern "C" {static PyObject *meth_QHelpSearchEngine_query(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_query(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            QList< ::QHelpSearchQuery>*sipRes;

            sipRes = new QList< ::QHelpSearchQuery>(sipCpp->query());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QHelpSearchQuery, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_query, doc_QHelpSearchEngine_query);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_queryWidget, "queryWidget(self) -> Optional[QHelpSearchQueryWidget]");

extern "C" {static PyObject *meth_QHelpSearchEngine_queryWidget(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_queryWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            ::QHelpSearchQueryWidget*sipRes;

            sipRes = sipCpp->queryWidget();

            return sipConvertFromType(sipRes, sipType_QHelpSearchQueryWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_queryWidget, doc_QHelpSearchEngine_queryWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_resultWidget, "resultWidget(self) -> Optional[QHelpSearchResultWidget]");

extern "C" {static PyObject *meth_QHelpSearchEngine_resultWidget(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_resultWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            ::QHelpSearchResultWidget*sipRes;

            sipRes = sipCpp->resultWidget();

            return sipConvertFromType(sipRes, sipType_QHelpSearchResultWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_resultWidget, doc_QHelpSearchEngine_resultWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_hitCount, "hitCount(self) -> int");

extern "C" {static PyObject *meth_QHelpSearchEngine_hitCount(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_hitCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->hitCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_hitCount, doc_QHelpSearchEngine_hitCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_hits, "hits(self, start: int, end: int) -> list[tuple[str, str]]");

extern "C" {static PyObject *meth_QHelpSearchEngine_hits(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_hits(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QHelpSearchEngine, &sipCpp, &a0, &a1))
        {
            QList<QPair<QString, QString>>*sipRes;

            sipRes = new QList<QPair<QString, QString>>(sipCpp->hits(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QList_0600QPair_0100QString_0100QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_hits, doc_QHelpSearchEngine_hits);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_reindexDocumentation, "reindexDocumentation(self)");

extern "C" {static PyObject *meth_QHelpSearchEngine_reindexDocumentation(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_reindexDocumentation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            sipCpp->reindexDocumentation();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_reindexDocumentation, doc_QHelpSearchEngine_reindexDocumentation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_cancelIndexing, "cancelIndexing(self)");

extern "C" {static PyObject *meth_QHelpSearchEngine_cancelIndexing(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_cancelIndexing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            sipCpp->cancelIndexing();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_cancelIndexing, doc_QHelpSearchEngine_cancelIndexing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_search, "search(self, queryList: Iterable[QHelpSearchQuery])\n"
"search(self, searchInput: Optional[str])");

extern "C" {static PyObject *meth_QHelpSearchEngine_search(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_search(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QHelpSearchQuery>* a0;
        int a0State = 0;
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpSearchEngine, &sipCpp, sipType_QList_0100QHelpSearchQuery, &a0, &a0State))
        {
            sipCpp->search(*a0);
            sipReleaseType(const_cast<QList< ::QHelpSearchQuery> *>(a0), sipType_QList_0100QHelpSearchQuery, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpSearchEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->search(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_search, doc_QHelpSearchEngine_search);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_cancelSearching, "cancelSearching(self)");

extern "C" {static PyObject *meth_QHelpSearchEngine_cancelSearching(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_cancelSearching(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            sipCpp->cancelSearching();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_cancelSearching, doc_QHelpSearchEngine_cancelSearching);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_searchResultCount, "searchResultCount(self) -> int");

extern "C" {static PyObject *meth_QHelpSearchEngine_searchResultCount(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_searchResultCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->searchResultCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_searchResultCount, doc_QHelpSearchEngine_searchResultCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_searchResults, "searchResults(self, start: int, end: int) -> list[QHelpSearchResult]");

extern "C" {static PyObject *meth_QHelpSearchEngine_searchResults(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_searchResults(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QHelpSearchEngine, &sipCpp, &a0, &a1))
        {
            QVector< ::QHelpSearchResult>*sipRes;

            sipRes = new QVector< ::QHelpSearchResult>(sipCpp->searchResults(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QHelpSearchResult, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_searchResults, doc_QHelpSearchEngine_searchResults);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpSearchEngine_searchInput, "searchInput(self) -> str");

extern "C" {static PyObject *meth_QHelpSearchEngine_searchInput(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchEngine_searchInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpSearchEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpSearchEngine, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->searchInput());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchEngine, sipName_searchInput, doc_QHelpSearchEngine_searchInput);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpSearchEngine(void *, const sipTypeDef *);}
static void *cast_QHelpSearchEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpSearchEngine *sipCpp = reinterpret_cast< ::QHelpSearchEngine *>(sipCppV);

    if (targetType == sipType_QHelpSearchEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpSearchEngine(void *, int);}
static void release_QHelpSearchEngine(void *sipCppV, int)
{
    ::QHelpSearchEngine *sipCpp = reinterpret_cast< ::QHelpSearchEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpSearchEngine(sipSimpleWrapper *);}
static void dealloc_QHelpSearchEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHelpSearchEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpSearchEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHelpSearchEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHelpSearchEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHelpSearchEngine *sipCpp = SIP_NULLPTR;

    {
        ::QHelpEngineCore* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QHelpEngineCore, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQHelpSearchEngine(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpSearchEngine[] = {{16, 0, 1}};


static PyMethodDef methods_QHelpSearchEngine[] = {
    {sipName_cancelIndexing, meth_QHelpSearchEngine_cancelIndexing, METH_VARARGS, doc_QHelpSearchEngine_cancelIndexing},
    {sipName_cancelSearching, meth_QHelpSearchEngine_cancelSearching, METH_VARARGS, doc_QHelpSearchEngine_cancelSearching},
    {sipName_hitCount, meth_QHelpSearchEngine_hitCount, METH_VARARGS, doc_QHelpSearchEngine_hitCount},
    {sipName_hits, meth_QHelpSearchEngine_hits, METH_VARARGS, doc_QHelpSearchEngine_hits},
    {sipName_query, meth_QHelpSearchEngine_query, METH_VARARGS, doc_QHelpSearchEngine_query},
    {sipName_queryWidget, meth_QHelpSearchEngine_queryWidget, METH_VARARGS, doc_QHelpSearchEngine_queryWidget},
    {sipName_reindexDocumentation, meth_QHelpSearchEngine_reindexDocumentation, METH_VARARGS, doc_QHelpSearchEngine_reindexDocumentation},
    {sipName_resultWidget, meth_QHelpSearchEngine_resultWidget, METH_VARARGS, doc_QHelpSearchEngine_resultWidget},
    {sipName_search, meth_QHelpSearchEngine_search, METH_VARARGS, doc_QHelpSearchEngine_search},
    {sipName_searchInput, meth_QHelpSearchEngine_searchInput, METH_VARARGS, doc_QHelpSearchEngine_searchInput},
    {sipName_searchResultCount, meth_QHelpSearchEngine_searchResultCount, METH_VARARGS, doc_QHelpSearchEngine_searchResultCount},
    {sipName_searchResults, meth_QHelpSearchEngine_searchResults, METH_VARARGS, doc_QHelpSearchEngine_searchResults}
};

PyDoc_STRVAR(doc_QHelpSearchEngine, "\1QHelpSearchEngine(helpEngine: Optional[QHelpEngineCore], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QHelpSearchEngine[] = {
    {"searchingFinished(int)", "\1searchingFinished(self, hits: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"searchingStarted()", "\1searchingStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"indexingFinished()", "\1indexingFinished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"indexingStarted()", "\1indexingStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QHelpSearchEngine = {
    &::QHelpSearchEngine::staticMetaObject,
    0,
    signals_QHelpSearchEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpSearchEngine,
        SIP_NULLPTR,
        &plugin_QHelpSearchEngine,
    },
    {
        sipNameNr_QHelpSearchEngine,
        {0, 0, 1},
        12, methods_QHelpSearchEngine,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHelpSearchEngine,
    -1,
    -1,
    supers_QHelpSearchEngine,
    SIP_NULLPTR,
    init_type_QHelpSearchEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpSearchEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpSearchEngine,
    cast_QHelpSearchEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QHelpSearchEngine),
};
