/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsview.sip"
#include <qgraphicsview.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsview.sip"
#include <qgraphicsview.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"


extern "C" {static long slot_QGraphicsView_OptimizationFlags___hash__(PyObject *);}
static long slot_QGraphicsView_OptimizationFlags___hash__(PyObject *sipSelf)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGraphicsView::OptimizationFlags::Int();
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QGraphicsView_OptimizationFlags___bool__(PyObject *);}
static int slot_QGraphicsView_OptimizationFlags___bool__(PyObject *sipSelf)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsView::OptimizationFlags::Int() != 0);
#line 76 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsView::OptimizationFlags::Int() != a0->operator QGraphicsView::OptimizationFlags::Int());
#line 106 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"
            sipReleaseType(const_cast< ::QGraphicsView::OptimizationFlags *>(a0), sipType_QGraphicsView_OptimizationFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, ne_slot, sipType_QGraphicsView_OptimizationFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGraphicsView::OptimizationFlags::Int() == a0->operator QGraphicsView::OptimizationFlags::Int());
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"
            sipReleaseType(const_cast< ::QGraphicsView::OptimizationFlags *>(a0), sipType_QGraphicsView_OptimizationFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, eq_slot, sipType_QGraphicsView_OptimizationFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___ixor__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsView_OptimizationFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        *sipCpp = QGraphicsView::OptimizationFlags(*sipCpp ^ a0);
#line 175 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___xor__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State, &a1))
        {
            ::QGraphicsView::OptimizationFlags*sipRes;

            sipRes = new ::QGraphicsView::OptimizationFlags((*a0 ^ a1));
            sipReleaseType(a0, sipType_QGraphicsView_OptimizationFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGraphicsView_OptimizationFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___ior__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsView_OptimizationFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        *sipCpp = QGraphicsView::OptimizationFlags(*sipCpp | a0);
#line 247 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___or__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State, &a1))
        {
            ::QGraphicsView::OptimizationFlags*sipRes;

            sipRes = new ::QGraphicsView::OptimizationFlags((*a0 | a1));
            sipReleaseType(a0, sipType_QGraphicsView_OptimizationFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGraphicsView_OptimizationFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___iand__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGraphicsView_OptimizationFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::QGraphicsView::OptimizationFlags::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___and__(PyObject *, PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State, &a1))
        {
            ::QGraphicsView::OptimizationFlags*sipRes;

            sipRes = new ::QGraphicsView::OptimizationFlags((*a0 & a1));
            sipReleaseType(a0, sipType_QGraphicsView_OptimizationFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGraphicsView_OptimizationFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtWidgets, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___invert__(PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___invert__(PyObject *sipSelf)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QGraphicsView::OptimizationFlags*sipRes;

            sipRes = new ::QGraphicsView::OptimizationFlags(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QGraphicsView_OptimizationFlags, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___index__(PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___index__(PyObject *sipSelf)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGraphicsView::OptimizationFlags::Int();
#line 404 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGraphicsView_OptimizationFlags___int__(PyObject *);}
static PyObject *slot_QGraphicsView_OptimizationFlags___int__(PyObject *sipSelf)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGraphicsView_OptimizationFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = int(*sipCpp);

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsView_OptimizationFlags(void *, int);}
static void release_QGraphicsView_OptimizationFlags(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipCppV);
}


extern "C" {static void *array_QGraphicsView_OptimizationFlags(Py_ssize_t);}
static void *array_QGraphicsView_OptimizationFlags(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsView::OptimizationFlags[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsView_OptimizationFlags(void *);}
static void array_delete_QGraphicsView_OptimizationFlags(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipCpp);
}


extern "C" {static void assign_QGraphicsView_OptimizationFlags(void *, Py_ssize_t, void *);}
static void assign_QGraphicsView_OptimizationFlags(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGraphicsView::OptimizationFlags *>(sipSrc);
}


extern "C" {static void *copy_QGraphicsView_OptimizationFlags(const void *, Py_ssize_t);}
static void *copy_QGraphicsView_OptimizationFlags(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGraphicsView::OptimizationFlags(reinterpret_cast<const ::QGraphicsView::OptimizationFlags *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGraphicsView_OptimizationFlags(sipSimpleWrapper *);}
static void dealloc_QGraphicsView_OptimizationFlags(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsView_OptimizationFlags(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGraphicsView_OptimizationFlags(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsView_OptimizationFlags(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGraphicsView::OptimizationFlags *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGraphicsView::OptimizationFlags();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QGraphicsView::OptimizationFlags(a0);

            return sipCpp;
        }
    }

    {
        const ::QGraphicsView::OptimizationFlags* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QGraphicsView_OptimizationFlags, &a0, &a0State))
        {
            sipCpp = new ::QGraphicsView::OptimizationFlags(*a0);
            sipReleaseType(const_cast< ::QGraphicsView::OptimizationFlags *>(a0), sipType_QGraphicsView_OptimizationFlags, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QGraphicsView_OptimizationFlags(PyObject *, void **, int *, PyObject *);}
static int convertTo_QGraphicsView_OptimizationFlags(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::QGraphicsView::OptimizationFlags **sipCppPtr = reinterpret_cast< ::QGraphicsView::OptimizationFlags **>(sipCppPtrV);

#line 127 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QGraphicsView::OptimizationFlags is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGraphicsView_OptimizationFlag)) ||
            sipCanConvertToType(sipPy, sipType_QGraphicsView_OptimizationFlags, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGraphicsView_OptimizationFlag)))
{
    *sipCppPtr = new QGraphicsView::OptimizationFlags(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QGraphicsView::OptimizationFlags *>(sipConvertToType(sipPy, sipType_QGraphicsView_OptimizationFlags, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 547 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsViewOptimizationFlags.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGraphicsView_OptimizationFlags[] = {
    {(void *)slot_QGraphicsView_OptimizationFlags___hash__, hash_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___bool__, bool_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___ne__, ne_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___eq__, eq_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___ixor__, ixor_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___xor__, xor_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___ior__, ior_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___or__, or_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___iand__, iand_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___and__, and_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___invert__, invert_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___index__, index_slot},
    {(void *)slot_QGraphicsView_OptimizationFlags___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QGraphicsView_OptimizationFlags, "\1QGraphicsView.OptimizationFlags()\n"
"QGraphicsView.OptimizationFlags(f: Union[QGraphicsView.OptimizationFlags, QGraphicsView.OptimizationFlag])\n"
"QGraphicsView.OptimizationFlags(a0: QGraphicsView.OptimizationFlags)");


static pyqt5ClassPluginDef plugin_QGraphicsView_OptimizationFlags = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView_OptimizationFlags = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsView__OptimizationFlags,
        SIP_NULLPTR,
        &plugin_QGraphicsView_OptimizationFlags,
    },
    {
        sipNameNr_OptimizationFlags,
        {164, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsView_OptimizationFlags,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGraphicsView_OptimizationFlags,
    init_type_QGraphicsView_OptimizationFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsView_OptimizationFlags,
    assign_QGraphicsView_OptimizationFlags,
    array_QGraphicsView_OptimizationFlags,
    copy_QGraphicsView_OptimizationFlags,
    release_QGraphicsView_OptimizationFlags,
    SIP_NULLPTR,
    convertTo_QGraphicsView_OptimizationFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsView_OptimizationFlags,
    sizeof (::QGraphicsView::OptimizationFlags),
};
