/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacereview.sip"
#include <qplacereview.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontent.sip"
#include <qplacecontent.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"
#line 360 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceuser.sip"
#include <qplaceuser.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesupplier.sip"
#include <qplacesupplier.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceReview.cpp"


class sipQPlaceReview : public ::QPlaceReview
{
public:
    sipQPlaceReview();
    sipQPlaceReview(const ::QPlaceContent&);
    sipQPlaceReview(const ::QPlaceReview&);
    ~sipQPlaceReview();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceReview(const sipQPlaceReview &);
    sipQPlaceReview &operator = (const sipQPlaceReview &);
};

sipQPlaceReview::sipQPlaceReview(): ::QPlaceReview(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceReview::sipQPlaceReview(const ::QPlaceContent& a0): ::QPlaceReview(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceReview::sipQPlaceReview(const ::QPlaceReview& a0): ::QPlaceReview(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceReview::~sipQPlaceReview()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceReview_dateTime, "dateTime(self) -> QDateTime");

extern "C" {static PyObject *meth_QPlaceReview_dateTime(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_dateTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->dateTime());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_dateTime, doc_QPlaceReview_dateTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setDateTime, "setDateTime(self, dt: Union[QDateTime, datetime.datetime])");

extern "C" {static PyObject *meth_QPlaceReview_setDateTime(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setDateTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceReview, &sipCpp, sipType_QDateTime, &a0, &a0State))
        {
            sipCpp->setDateTime(*a0);
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setDateTime, doc_QPlaceReview_setDateTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_text, "text(self) -> str");

extern "C" {static PyObject *meth_QPlaceReview_text(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_text, doc_QPlaceReview_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setText, "setText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QPlaceReview_setText(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceReview, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setText, doc_QPlaceReview_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_language, "language(self) -> str");

extern "C" {static PyObject *meth_QPlaceReview_language(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_language(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->language());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_language, doc_QPlaceReview_language);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setLanguage, "setLanguage(self, data: Optional[str])");

extern "C" {static PyObject *meth_QPlaceReview_setLanguage(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setLanguage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceReview, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLanguage(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setLanguage, doc_QPlaceReview_setLanguage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_rating, "rating(self) -> float");

extern "C" {static PyObject *meth_QPlaceReview_rating(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_rating(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->rating();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_rating, doc_QPlaceReview_rating);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setRating, "setRating(self, data: float)");

extern "C" {static PyObject *meth_QPlaceReview_setRating(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setRating(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPlaceReview, &sipCpp, &a0))
        {
            sipCpp->setRating(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setRating, doc_QPlaceReview_setRating);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_reviewId, "reviewId(self) -> str");

extern "C" {static PyObject *meth_QPlaceReview_reviewId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_reviewId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->reviewId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_reviewId, doc_QPlaceReview_reviewId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setReviewId, "setReviewId(self, identifier: Optional[str])");

extern "C" {static PyObject *meth_QPlaceReview_setReviewId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setReviewId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceReview, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setReviewId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setReviewId, doc_QPlaceReview_setReviewId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_title, "title(self) -> str");

extern "C" {static PyObject *meth_QPlaceReview_title(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceReview, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_title, doc_QPlaceReview_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceReview_setTitle, "setTitle(self, data: Optional[str])");

extern "C" {static PyObject *meth_QPlaceReview_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QPlaceReview_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceReview *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceReview, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceReview, sipName_setTitle, doc_QPlaceReview_setTitle);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPlaceReview(void *, const sipTypeDef *);}
static void *cast_QPlaceReview(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPlaceReview *sipCpp = reinterpret_cast< ::QPlaceReview *>(sipCppV);

    if (targetType == sipType_QPlaceReview)
        return sipCppV;

    if (targetType == sipType_QPlaceContent)
        return static_cast< ::QPlaceContent *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceReview(void *, int);}
static void release_QPlaceReview(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceReview *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceReview *>(sipCppV);
}


extern "C" {static void *array_QPlaceReview(Py_ssize_t);}
static void *array_QPlaceReview(Py_ssize_t sipNrElem)
{
    return new ::QPlaceReview[sipNrElem];
}


extern "C" {static void array_delete_QPlaceReview(void *);}
static void array_delete_QPlaceReview(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceReview *>(sipCpp);
}


extern "C" {static void assign_QPlaceReview(void *, Py_ssize_t, void *);}
static void assign_QPlaceReview(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceReview *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceReview *>(sipSrc);
}


extern "C" {static void *copy_QPlaceReview(const void *, Py_ssize_t);}
static void *copy_QPlaceReview(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceReview(reinterpret_cast<const ::QPlaceReview *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceReview(sipSimpleWrapper *);}
static void dealloc_QPlaceReview(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceReview *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceReview(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceReview(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceReview(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceReview *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceReview();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceContent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceContent, &a0))
        {
            sipCpp = new sipQPlaceReview(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceReview* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceReview, &a0))
        {
            sipCpp = new sipQPlaceReview(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPlaceReview[] = {{57, 255, 1}};


static PyMethodDef methods_QPlaceReview[] = {
    {sipName_dateTime, meth_QPlaceReview_dateTime, METH_VARARGS, doc_QPlaceReview_dateTime},
    {sipName_language, meth_QPlaceReview_language, METH_VARARGS, doc_QPlaceReview_language},
    {sipName_rating, meth_QPlaceReview_rating, METH_VARARGS, doc_QPlaceReview_rating},
    {sipName_reviewId, meth_QPlaceReview_reviewId, METH_VARARGS, doc_QPlaceReview_reviewId},
    {sipName_setDateTime, meth_QPlaceReview_setDateTime, METH_VARARGS, doc_QPlaceReview_setDateTime},
    {sipName_setLanguage, meth_QPlaceReview_setLanguage, METH_VARARGS, doc_QPlaceReview_setLanguage},
    {sipName_setRating, meth_QPlaceReview_setRating, METH_VARARGS, doc_QPlaceReview_setRating},
    {sipName_setReviewId, meth_QPlaceReview_setReviewId, METH_VARARGS, doc_QPlaceReview_setReviewId},
    {sipName_setText, meth_QPlaceReview_setText, METH_VARARGS, doc_QPlaceReview_setText},
    {sipName_setTitle, meth_QPlaceReview_setTitle, METH_VARARGS, doc_QPlaceReview_setTitle},
    {sipName_text, meth_QPlaceReview_text, METH_VARARGS, doc_QPlaceReview_text},
    {sipName_title, meth_QPlaceReview_title, METH_VARARGS, doc_QPlaceReview_title}
};

PyDoc_STRVAR(doc_QPlaceReview, "\1QPlaceReview()\n"
"QPlaceReview(other: QPlaceContent)\n"
"QPlaceReview(a0: QPlaceReview)");


static pyqt5ClassPluginDef plugin_QPlaceReview = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceReview = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceReview,
        SIP_NULLPTR,
        &plugin_QPlaceReview,
    },
    {
        sipNameNr_QPlaceReview,
        {0, 0, 1},
        12, methods_QPlaceReview,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceReview,
    -1,
    -1,
    supers_QPlaceReview,
    SIP_NULLPTR,
    init_type_QPlaceReview,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceReview,
    assign_QPlaceReview,
    array_QPlaceReview,
    copy_QPlaceReview,
    release_QPlaceReview,
    cast_QPlaceReview,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceReview,
    sizeof (::QPlaceReview),
};
